==> ingdao-0.0.2.tar.gz: lib/dataflow/field/dfdbfield.dart <==
import 'package:meta/meta.dart';
import 'dfbasefield.dart';
import '../entity/dfbaseentity.dart';
import '../field/dffieldtype.dart';
import '../control/dfconverter.dart';

enum FieldType {
  text,
  integer,
  real,
  blob
}

extension FieldTypeExtension on FieldType {

  String get name {
    switch (this) {
      case FieldType.text:
        return 'TEXT';
      case FieldType.integer:
        return 'INTEGER';
     case FieldType.real:
        return 'REAL';
     case FieldType.blob:
        return 'BLOB';                
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DfDbField extends DfBaseField {

  bool primaryKey;
  bool joinKey;
  //FieldType type;
  bool displayOnly;

  DfDbField({@required DfBaseEntity entity, @required String name, @required DfFieldType fieldType, @required this.primaryKey, @required this.joinKey, /*@required this.type,*/ this.displayOnly, dynamic value}) : super(entity: entity, name: name, fieldType: fieldType, displayOnly: displayOnly, value: value);

    String toCreateFieldStr() {
     String typeStr = fieldType.type.name; //type.name;
     return "$name $typeStr";
   }

   String getSelectQueryField() {
     if (name.toLowerCase().indexOf("count(") >= 0) {
       return "count(*) as ${entity.name}_count";
     }
     return "${entity.name}.$name as ${entity.name}_$name";
   }

   String getSelectQueryAlias() {
     return "${entity.name}_$name";
   }

   setValueFromQueryResult(Map<String,dynamic> dict) {
    value = dict[getSelectQueryAlias()];
    if (value != null) {
      if (fieldType.isDateTime && value is String && value.length > 0) {
        value = DfConverter.stringToDate(value);
      }
      else if (fieldType.isBoolean && value is int) {
        value = DfConverter.intToBool(value);
      }
    }    
   }

}

==> ingdao-0.0.6.tar.gz: lib/dataflow/field/dfdbfield.dart <==
import 'package:meta/meta.dart';
import 'dfbasefield.dart';
import '../entity/dfbaseentity.dart';
import '../field/dffieldtype.dart';
import '../control/dfconverter.dart';

enum FieldType {
  text,
  integer,
  real,
  blob
}

extension FieldTypeExtension on FieldType {

  String get name {
    switch (this) {
      case FieldType.text:
        return 'TEXT';
      case FieldType.integer:
        return 'INTEGER';
     case FieldType.real:
        return 'REAL';
     case FieldType.blob:
        return 'BLOB';                
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DfDbField extends DfBaseField {

  bool primaryKey;
  bool joinKey;
  //FieldType type;
  bool displayOnly;

  DfDbField({@required DfBaseEntity entity, @required String name, @required DfFieldType fieldType, @required this.primaryKey, @required this.joinKey, /*@required this.type,*/ this.displayOnly, Function getObjectValue, Function setObjectValue, dynamic value}) : super(entity: entity, name: name, fieldType: fieldType, displayOnly: displayOnly, getObjectValue: getObjectValue, setObjectValue: setObjectValue, value: value);

    String toCreateFieldStr() {
     String typeStr = fieldType.type.name; //type.name;
     return "$name $typeStr";
   }

   String getSelectQueryField() {
     if (name.toLowerCase().indexOf("count(") >= 0) {
       return "count(*) as ${entity.entityName}_count";
     }
     return "${entity.entityName}.$name as ${entity.entityName}_$name";
   }

   String getSelectQueryAlias() {
     return "${entity.entityName}_$name";
   }

   setValueFromQueryResult(Map<String,dynamic> dict) {
    value = dict[getSelectQueryAlias()];
    if (value != null) {
      if (fieldType.isDateTime && value is String && value.length > 0) {
        value = DfConverter.stringToDate(value);
      }
      else if (fieldType.isBoolean && value is int) {
        value = DfConverter.intToBool(value);
      }
    }    
   }

}
